Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1255)

Unified Diff: webrtc/media/engine/webrtcvoiceengine.h

Issue 1952123003: Surface the IntelligibilityEnhancer on MediaConstraints (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Change to use MediaConstraints Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/media/engine/webrtcvoiceengine.h
diff --git a/webrtc/media/engine/webrtcvoiceengine.h b/webrtc/media/engine/webrtcvoiceengine.h
index 1cc550430435b4dedadd20144c0ce0c109119be0..29f9eed54c4dc7aa422733dd8f00c4d77743c5f8 100644
--- a/webrtc/media/engine/webrtcvoiceengine.h
+++ b/webrtc/media/engine/webrtcvoiceengine.h
@@ -120,13 +120,14 @@ class WebRtcVoiceEngine final : public webrtc::TraceCallback {
bool is_dumping_aec_ = false;
webrtc::AgcConfig default_agc_config_;
// Cache received extended_filter_aec, delay_agnostic_aec and experimental_ns
// values, and apply them in case they are missing in the audio options. We
// need to do this because SetExtraOptions() will revert to defaults for
// options which are not provided.
rtc::Optional<bool> extended_filter_aec_;
rtc::Optional<bool> delay_agnostic_aec_;
rtc::Optional<bool> experimental_ns_;
+ rtc::Optional<bool> intelligibility_enhancer_;
RTC_DISALLOW_IMPLICIT_CONSTRUCTORS(WebRtcVoiceEngine);
};
@@ -120,13 +120,14 @@ class WebRtcVoiceEngine final : public webrtc::TraceCallback {
bool is_dumping_aec_ = false;
webrtc::AgcConfig default_agc_config_;
- // Cache received extended_filter_aec, delay_agnostic_aec and experimental_ns
- // values, and apply them in case they are missing in the audio options. We
- // need to do this because SetExtraOptions() will revert to defaults for
- // options which are not provided.
+ // Cache received extended_filter_aec, delay_agnostic_aec, experimental_ns and
+ // intelligibility_enhancer values, and apply them in case they are missing
+ // in the audio options. We need to do this because SetExtraOptions() will
+ // revert to defaults for options which are not provided.
rtc::Optional<bool> extended_filter_aec_;
rtc::Optional<bool> delay_agnostic_aec_;

Powered by Google App Engine
This is Rietveld 408576698